# Docs

## Requirements

> NOTE: `The requirements.txt` is only for Read the Docs.

```bash
sudo apt install doxygen
```

All other dependencies are installed in the setup below when you call `make docs`.

## Setup
```bash
# From the root project dir
make docs
```

Look at the locally served docs at http://0.0.0.0:1900.

## Benchmark Results

The benchmark results are stored in `docs/benchmark_results/` and tables in the docs are automatically generated from the CSV files.
